@@ -1,24 +1,25 @@
 from __future__ import annotations
 
 from functools import lru_cache
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 import duckdb
 from duckdb import Expression
 
-try:
-    import duckdb.sqltypes as duckdb_dtypes
-except ModuleNotFoundError:
-    # DuckDB pre 1.3
-    import duckdb.typing as duckdb_dtypes
-
-from narwhals._utils import Version, extend_bool, isinstance_or_issubclass, zip_strict
+from narwhals._utils import (
+    Implementation,
+    Version,
+    extend_bool,
+    isinstance_or_issubclass,
+    zip_strict,
+)
 from narwhals.exceptions import ColumnNotFoundError
 
 if TYPE_CHECKING:
     from collections.abc import Mapping, Sequence
 
     from duckdb import DuckDBPyRelation
+    from typing_extensions import TypeAlias
 
     from narwhals._compliant.typing import CompliantLazyFrameAny
     from narwhals._duckdb.dataframe import DuckDBLazyFrame
@@ -26,6 +27,18 @@ if TYPE_CHECKING:
     from narwhals.dtypes import DType
     from narwhals.typing import IntoDType, TimeUnit
 
+Incomplete: TypeAlias = Any
+"""Review if an progress is made towards [#131].
+
+[#131]: https://github.com/duckdb/duckdb-python/issues/131"""
+
+BACKEND_VERSION = Implementation.DUCKDB._backend_version()
+"""Static backend version for `duckdb`."""
+
+if TYPE_CHECKING or BACKEND_VERSION >= (1, 4):
+    from duckdb import sqltypes as duckdb_dtypes
+else:  # pragma: no cover
+    from duckdb import typing as duckdb_dtypes
 
 UNITS_DICT = {
     "y": "year",
@@ -87,12 +100,12 @@ def concat_str(*exprs: Expression, separator: str = "") -> Expression:
     return F("concat_ws", lit(separator), *exprs) if separator else F("concat", *exprs)
 
 
-def evaluate_exprs(
+def evaluate_exprs_and_aliases(
     df: DuckDBLazyFrame, /, *exprs: DuckDBExpr
 ) -> list[tuple[str, Expression]]:
     native_results: list[tuple[str, Expression]] = []
     for expr in exprs:
-        native_series_list = expr._call(df)
+        native_series_list = expr(df)
         output_names = expr._evaluate_output_names(df)
         if expr._alias_output_names is not None:
             output_names = expr._alias_output_names(output_names)
@@ -139,7 +152,7 @@ def native_to_narwhals_dtype(
     version: Version,
     deferred_time_zone: DeferredTimeZone,
 ) -> DType:
-    duckdb_dtype_id = duckdb_dtype.id
+    duckdb_dtype_id: str = duckdb_dtype.id
     dtypes = version.dtypes
 
     # Handle nested data types first
@@ -149,7 +162,7 @@ def native_to_narwhals_dtype(
         )
 
     if duckdb_dtype_id == "struct":
-        children = duckdb_dtype.children
+        children: list[tuple[Incomplete, Incomplete]] = duckdb_dtype.children
         return dtypes.Struct(
             [
                 dtypes.Field(
@@ -161,8 +174,10 @@ def native_to_narwhals_dtype(
         )
 
     if duckdb_dtype_id == "array":
+        child: Incomplete
+        size: Incomplete
         child, size = duckdb_dtype.children
-        shape: list[int] = [size[1]]
+        shape = [size[1]]
 
         while child[1].id == "array":
             child, size = child[1].children
@@ -174,12 +189,18 @@ def native_to_narwhals_dtype(
     if duckdb_dtype_id == "enum":
         if version is Version.V1:
             return dtypes.Enum()  # type: ignore[call-arg]
-        categories = duckdb_dtype.children[0][1]
-        return dtypes.Enum(categories=categories)
+        categories: Incomplete = duckdb_dtype.children[0][1]
+        return dtypes.Enum(categories)
 
     if duckdb_dtype_id == "timestamp with time zone":
         return dtypes.Datetime(time_zone=deferred_time_zone.time_zone)
 
+    if duckdb_dtype_id == "decimal":
+        precision: Incomplete
+        scale: Incomplete
+        (_, precision), (_, scale) = duckdb_dtype.children
+        return dtypes.Decimal(precision, scale)
+
     return _non_nested_native_to_narwhals_dtype(duckdb_dtype_id, version)
 
 
@@ -215,7 +236,6 @@ def _non_nested_native_to_narwhals_dtype(duckdb_dtype_id: str, version: Version)
         "timestamp_ns": dtypes.Datetime("ns"),
         "boolean": dtypes.Boolean(),
         "interval": dtypes.Duration(),
-        "decimal": dtypes.Decimal(),
         "time": dtypes.Time(),
         "blob": dtypes.Binary(),
     }.get(duckdb_dtype_id, dtypes.Unknown())
@@ -247,7 +267,7 @@ TIME_UNIT_TO_TIMESTAMP: Mapping[TimeUnit, duckdb_dtypes.DuckDBPyType] = {
     "us": duckdb_dtypes.TIMESTAMP,
     "ns": duckdb_dtypes.TIMESTAMP_NS,
 }
-UNSUPPORTED_DTYPES = (dtypes.Decimal, dtypes.Categorical)
+UNSUPPORTED_DTYPES = dtypes.Categorical
 
 
 def narwhals_to_native_dtype(  # noqa: PLR0912, C901
@@ -298,6 +318,8 @@ def narwhals_to_native_dtype(  # noqa: PLR0912, C901
         duckdb_inner = narwhals_to_native_dtype(nw_inner, version, deferred_time_zone)
         duckdb_shape_fmt = "".join(f"[{item}]" for item in dtype.shape)
         return duckdb_dtypes.DuckDBPyType(f"{duckdb_inner}{duckdb_shape_fmt}")
+    if isinstance(dtype, dtypes.Decimal):
+        return duckdb_dtypes.DuckDBPyType(f"DECIMAL({dtype.precision}, {dtype.scale})")
     if issubclass(base_type, UNSUPPORTED_DTYPES):
         msg = f"Converting to {base_type.__name__} dtype is not supported for DuckDB."
         raise NotImplementedError(msg)
@@ -406,7 +428,6 @@ __all__ = [
     "col",
     "concat_str",
     "duckdb_dtypes",
-    "evaluate_exprs",
     "fetch_rel_time_zone",
     "function",
     "generate_order_by_sql",
