@@ -185,6 +185,18 @@ class PolarsExpr:
         )
         return self._with_native(native)
 
+    def first(self, order_by: Sequence[str] = ()) -> Self:
+        if order_by:
+            # Can't use `min_by` / `max_by` as they skip nulls.
+            return self._with_native(self.native.sort_by(*order_by).first())
+        return self._with_native(self.native.first())
+
+    def last(self, order_by: Sequence[str] = ()) -> Self:
+        if order_by:
+            # Can't use `min_by` / `max_by` as they skip nulls.
+            return self._with_native(self.native.sort_by(*order_by).last())
+        return self._with_native(self.native.last())
+
     def rolling_sum(self, window_size: int, *, min_samples: int, center: bool) -> Self:
         kwds = self._renamed_min_periods(min_samples)
         native = self.native.rolling_sum(window_size=window_size, center=center, **kwds)
@@ -336,6 +348,7 @@ class PolarsExpr:
     arg_true: Method[Self]
     ceil: Method[Self]
     count: Method[Self]
+    cos: Method[Self]
     cum_max: Method[Self]
     cum_min: Method[Self]
     cum_prod: Method[Self]
@@ -345,9 +358,7 @@ class PolarsExpr:
     exp: Method[Self]
     fill_null: Method[Self]
     fill_nan: Method[Self]
-    first: Method[Self]
     floor: Method[Self]
-    last: Method[Self]
     gather_every: Method[Self]
     head: Method[Self]
     is_between: Method[Self]
