@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import operator
 from functools import reduce
+from itertools import chain
 from typing import TYPE_CHECKING, Any
 
 from narwhals._expression_parsing import (
@@ -18,17 +19,16 @@ from narwhals._spark_like.utils import (
     true_divide,
 )
 from narwhals._sql.namespace import SQLNamespace
-from narwhals._sql.when_then import SQLThen, SQLWhen
-from narwhals._utils import zip_strict
 
 if TYPE_CHECKING:
     from collections.abc import Iterable
 
     from sqlframe.base.column import Column
 
+    from narwhals._compliant.window import WindowInputs
     from narwhals._spark_like.dataframe import SQLFrameDataFrame  # noqa: F401
     from narwhals._utils import Implementation, Version
-    from narwhals.typing import ConcatMethod, IntoDType, NonNestedLiteral, PythonLiteral
+    from narwhals.typing import ConcatMethod, IntoDType, PythonLiteral
 
 # Adjust slight SQL vs PySpark differences
 FUNCTION_REMAPPINGS = {
@@ -91,9 +91,22 @@ class SparkLikeNamespace(
     def _coalesce(self, *exprs: Column) -> Column:
         return self._F.coalesce(*exprs)
 
-    def lit(self, value: NonNestedLiteral, dtype: IntoDType | None) -> SparkLikeExpr:
-        def _lit(df: SparkLikeLazyFrame) -> list[Column]:
-            column = df._F.lit(value)
+    def lit(self, value: PythonLiteral, dtype: IntoDType | None) -> SparkLikeExpr:
+        def func(df: SparkLikeLazyFrame) -> list[Column]:
+            F = df._F
+
+            if isinstance(value, (list, tuple)):
+                lit_values = [F.lit(v) for v in value]
+                column = F.lit(F.array(lit_values))
+            elif isinstance(value, dict):
+                if (not self._implementation.is_pyspark()) and (len(value) == 0):
+                    msg = f"Cannot create an empty struct type for {self._implementation} backend"
+                    raise NotImplementedError(msg)
+                lit_values = [F.lit(v).alias(k) for k, v in value.items()]
+                column = F.struct(*lit_values)
+            else:
+                column = F.lit(value)
+
             if dtype:
                 native_dtype = narwhals_to_native_dtype(
                     dtype, self._version, df._native_dtypes, df.native.sparkSession
@@ -102,8 +115,14 @@ class SparkLikeNamespace(
 
             return [column]
 
+        def window_func(
+            df: SparkLikeLazyFrame, _window_inputs: WindowInputs[Column]
+        ) -> list[Column]:
+            return func(df)
+
         return self._expr(
-            call=_lit,
+            func,
+            window_func,
             evaluate_output_names=lambda _df: ["literal"],
             alias_output_names=None,
             version=self._version,
@@ -173,37 +192,13 @@ class SparkLikeNamespace(
         self, *exprs: SparkLikeExpr, separator: str, ignore_nulls: bool
     ) -> SparkLikeExpr:
         def func(df: SparkLikeLazyFrame) -> list[Column]:
-            cols = [s for _expr in exprs for s in _expr(df)]
-            cols_casted = [s.cast(df._native_dtypes.StringType()) for s in cols]
-            null_mask = [df._F.isnull(s) for s in cols]
+            F = self._F
+            cols = tuple(chain.from_iterable(e(df) for e in exprs))
+            result = F.concat_ws(separator, *cols)
 
             if not ignore_nulls:
-                null_mask_result = reduce(operator.or_, null_mask)
-                result = df._F.when(
-                    ~null_mask_result,
-                    reduce(
-                        lambda x, y: df._F.format_string(f"%s{separator}%s", x, y),
-                        cols_casted,
-                    ),
-                ).otherwise(df._F.lit(None))
-            else:
-                init_value, *values = [
-                    df._F.when(~nm, col).otherwise(df._F.lit(""))
-                    for col, nm in zip_strict(cols_casted, null_mask)
-                ]
-
-                separators = (
-                    df._F.when(nm, df._F.lit("")).otherwise(df._F.lit(separator))
-                    for nm in null_mask[:-1]
-                )
-                result = reduce(
-                    lambda x, y: df._F.format_string("%s%s", x, y),
-                    (
-                        df._F.format_string("%s%s", s, v)
-                        for s, v in zip_strict(separators, values)
-                    ),
-                    init_value,
-                )
+                null_mask = reduce(operator.or_, (F.isnull(s) for s in cols))
+                result = F.when(~null_mask, result).otherwise(F.lit(None))
 
             return [result]
 
@@ -214,17 +209,3 @@ class SparkLikeNamespace(
             version=self._version,
             implementation=self._implementation,
         )
-
-    def when(self, predicate: SparkLikeExpr) -> SparkLikeWhen:
-        return SparkLikeWhen.from_expr(predicate, context=self)
-
-
-class SparkLikeWhen(SQLWhen[SparkLikeLazyFrame, "Column", SparkLikeExpr]):
-    @property
-    def _then(self) -> type[SparkLikeThen]:
-        return SparkLikeThen
-
-
-class SparkLikeThen(
-    SQLThen[SparkLikeLazyFrame, "Column", SparkLikeExpr], SparkLikeExpr
-): ...
