@@ -12,11 +12,13 @@ from narwhals._utils import (
     isinstance_or_issubclass,
     qualified_type_name,
 )
+from narwhals.exceptions import InvalidOperationError
 
 if TYPE_CHECKING:
     from collections.abc import Iterator, Sequence
     from typing import Any
 
+    import _typeshed
     from typing_extensions import Self, TypeIs
 
     from narwhals.typing import IntoDType, TimeUnit
@@ -33,14 +35,12 @@ def _validate_dtype(dtype: DType | type[DType]) -> None:
 
 def _is_into_dtype(obj: Any) -> TypeIs[IntoDType]:
     return isinstance(obj, DType) or (
-        isinstance(obj, type)
-        and issubclass(obj, DType)
-        and not issubclass(obj, NestedType)
+        isinstance(obj, DTypeClass) and not issubclass(obj, NestedType)
     )
 
 
 def _is_nested_type(obj: Any) -> TypeIs[type[NestedType]]:
-    return isinstance(obj, type) and issubclass(obj, NestedType)
+    return isinstance(obj, DTypeClass) and issubclass(obj, NestedType)
 
 
 def _validate_into_dtype(dtype: Any) -> None:
@@ -59,10 +59,40 @@ def _validate_into_dtype(dtype: Any) -> None:
         raise TypeError(msg)
 
 
-class DType:
-    __slots__ = ()
+class DTypeClass(type):
+    """Metaclass for DType classes.
 
-    def __repr__(self) -> str:  # pragma: no cover
+    - Nicely print classes.
+    - Ensure [`__slots__`] are always defined to prevent `__dict__` creation (empty by default).
+
+    [`__slots__`]: https://docs.python.org/3/reference/datamodel.html#object.__slots__
+    """
+
+    def __repr__(cls) -> str:
+        return cls.__name__
+
+    # https://github.com/python/typeshed/blob/776508741d76b58f9dcb2aaf42f7d4596a48d580/stdlib/abc.pyi#L13-L19
+    # https://github.com/python/typeshed/blob/776508741d76b58f9dcb2aaf42f7d4596a48d580/stdlib/_typeshed/__init__.pyi#L36-L40
+    # https://github.com/astral-sh/ruff/issues/8353#issuecomment-1786238311
+    # https://docs.python.org/3/reference/datamodel.html#creating-the-class-object
+    def __new__(
+        metacls: type[_typeshed.Self],
+        cls_name: str,
+        bases: tuple[type, ...],
+        namespace: dict[str, Any],
+        /,
+        **kwds: Any,
+    ) -> _typeshed.Self:
+        namespace.setdefault("__slots__", ())
+        return super().__new__(metacls, cls_name, bases, namespace, **kwds)  # type: ignore[no-any-return, misc]
+
+
+class DType(metaclass=DTypeClass):
+    """Base class for all Narwhals data types."""
+
+    __slots__ = ()  # NOTE: Keep this one defined manually for the type checker
+
+    def __repr__(self) -> str:
         return self.__class__.__qualname__
 
     @classmethod
@@ -72,13 +102,11 @@ class DType:
         Examples:
             >>> import narwhals as nw
             >>> nw.Datetime("us").base_type()
-            <class 'narwhals.dtypes.Datetime'>
-
+            Datetime
             >>> nw.String.base_type()
-            <class 'narwhals.dtypes.String'>
-
+            String
             >>> nw.List(nw.Int64).base_type()
-            <class 'narwhals.dtypes.List'>
+            List
         """
         return cls
 
@@ -143,8 +171,6 @@ class DType:
             >>> nw.Date() == nw.Datetime
             False
         """
-        from narwhals._utils import isinstance_or_issubclass
-
         return isinstance_or_issubclass(other, type(self))
 
     def __hash__(self) -> int:
@@ -154,57 +180,85 @@ class DType:
 class NumericType(DType):
     """Base class for numeric data types."""
 
-    __slots__ = ()
-
 
 class IntegerType(NumericType):
     """Base class for integer data types."""
 
-    __slots__ = ()
-
 
 class SignedIntegerType(IntegerType):
     """Base class for signed integer data types."""
 
-    __slots__ = ()
-
 
 class UnsignedIntegerType(IntegerType):
     """Base class for unsigned integer data types."""
 
-    __slots__ = ()
-
 
 class FloatType(NumericType):
     """Base class for float data types."""
 
-    __slots__ = ()
-
 
 class TemporalType(DType):
     """Base class for temporal data types."""
 
-    __slots__ = ()
-
 
 class NestedType(DType):
     """Base class for nested data types."""
 
-    __slots__ = ()
-
 
 class Decimal(NumericType):
-    """Decimal type.
+    """Decimal 128-bit type with an optional precision and non-negative scale.
+
+    Arguments:
+        precision: Maximum number of digits in each number. If set to `None` (default),
+            the precision is set to 38 (the maximum supported by Polars).
+        scale: Number of digits to the right of the decimal point in each number.
 
     Examples:
         >>> import polars as pl
         >>> import narwhals as nw
         >>> s = pl.Series(["1.5"], dtype=pl.Decimal)
         >>> nw.from_native(s, series_only=True).dtype
-        Decimal
+        Decimal(precision=2, scale=1)
     """
 
-    __slots__ = ()
+    __slots__ = ("precision", "scale")
+
+    precision: int
+    scale: int
+
+    # !NOTE: Reason for `precision: int | None = None` rather than `precision: int = 38`
+    # is to mirror polars signature https://github.com/pola-rs/polars/blob/bb79993c3aa91d0db7d20be8f75c8075cad97067/py-polars/src/polars/datatypes/classes.py#L450-L454
+    def __init__(self, precision: int | None = None, scale: int = 0) -> None:
+        precision = 38 if precision is None else precision
+
+        if not ((is_int := isinstance(precision, int)) and 0 <= precision <= 38):
+            msg = f"precision must be a positive integer between 0 and 38, found {precision!r}"
+            raise ValueError(msg) if is_int else TypeError(msg)
+
+        if not ((is_int := isinstance(scale, int)) and scale >= 0):
+            msg = f"scale must be a positive integer, found {scale!r}"
+            raise ValueError(msg) if is_int else TypeError(msg)
+
+        if scale > precision:
+            msg = "scale must be less than or equal to precision"
+            raise InvalidOperationError(msg)
+
+        self.precision = precision
+        self.scale = scale
+
+    def __eq__(self, other: DType | type[DType]) -> bool:  # type: ignore[override]
+        return (other is Decimal) or (
+            isinstance(other, self.__class__)
+            and self.precision == other.precision
+            and self.scale == other.scale
+        )
+
+    def __hash__(self) -> int:  # pragma: no cover
+        return hash((self.__class__, self.precision, self.scale))
+
+    def __repr__(self) -> str:  # pragma: no cover
+        class_name = self.__class__.__name__
+        return f"{class_name}(precision={self.precision!r}, scale={self.scale!r})"
 
 
 class Int128(SignedIntegerType):
@@ -226,8 +280,6 @@ class Int128(SignedIntegerType):
         Int128
     """
 
-    __slots__ = ()
-
 
 class Int64(SignedIntegerType):
     """64-bit signed integer type.
@@ -241,8 +293,6 @@ class Int64(SignedIntegerType):
         Int64
     """
 
-    __slots__ = ()
-
 
 class Int32(SignedIntegerType):
     """32-bit signed integer type.
@@ -256,8 +306,6 @@ class Int32(SignedIntegerType):
         Int32
     """
 
-    __slots__ = ()
-
 
 class Int16(SignedIntegerType):
     """16-bit signed integer type.
@@ -271,8 +319,6 @@ class Int16(SignedIntegerType):
         Int16
     """
 
-    __slots__ = ()
-
 
 class Int8(SignedIntegerType):
     """8-bit signed integer type.
@@ -286,8 +332,6 @@ class Int8(SignedIntegerType):
         Int8
     """
 
-    __slots__ = ()
-
 
 class UInt128(UnsignedIntegerType):
     """128-bit unsigned integer type.
@@ -302,8 +346,6 @@ class UInt128(UnsignedIntegerType):
         UInt128
     """
 
-    __slots__ = ()
-
 
 class UInt64(UnsignedIntegerType):
     """64-bit unsigned integer type.
@@ -317,8 +359,6 @@ class UInt64(UnsignedIntegerType):
         UInt64
     """
 
-    __slots__ = ()
-
 
 class UInt32(UnsignedIntegerType):
     """32-bit unsigned integer type.
@@ -332,8 +372,6 @@ class UInt32(UnsignedIntegerType):
         UInt32
     """
 
-    __slots__ = ()
-
 
 class UInt16(UnsignedIntegerType):
     """16-bit unsigned integer type.
@@ -347,8 +385,6 @@ class UInt16(UnsignedIntegerType):
         UInt16
     """
 
-    __slots__ = ()
-
 
 class UInt8(UnsignedIntegerType):
     """8-bit unsigned integer type.
@@ -362,8 +398,6 @@ class UInt8(UnsignedIntegerType):
         UInt8
     """
 
-    __slots__ = ()
-
 
 class Float64(FloatType):
     """64-bit floating point type.
@@ -377,8 +411,6 @@ class Float64(FloatType):
         Float64
     """
 
-    __slots__ = ()
-
 
 class Float32(FloatType):
     """32-bit floating point type.
@@ -392,8 +424,6 @@ class Float32(FloatType):
         Float32
     """
 
-    __slots__ = ()
-
 
 class String(DType):
     """UTF-8 encoded string type.
@@ -406,8 +436,6 @@ class String(DType):
         String
     """
 
-    __slots__ = ()
-
 
 class Boolean(DType):
     """Boolean type.
@@ -420,8 +448,6 @@ class Boolean(DType):
         Boolean
     """
 
-    __slots__ = ()
-
 
 class Object(DType):
     """Data type for wrapping arbitrary Python objects.
@@ -435,8 +461,6 @@ class Object(DType):
         Object
     """
 
-    __slots__ = ()
-
 
 class Unknown(DType):
     """Type representing DataType values that could not be determined statically.
@@ -449,10 +473,8 @@ class Unknown(DType):
         Unknown
     """
 
-    __slots__ = ()
 
-
-class _DatetimeMeta(type):
+class _DatetimeMeta(DTypeClass):
     @property
     def time_unit(cls) -> TimeUnit:
         """Unit of time. Defaults to `'us'` (microseconds)."""
@@ -546,7 +568,7 @@ class Datetime(TemporalType, metaclass=_DatetimeMeta):
         return f"{class_name}(time_unit={self.time_unit!r}, time_zone={self.time_zone!r})"
 
 
-class _DurationMeta(type):
+class _DurationMeta(DTypeClass):
     @property
     def time_unit(cls) -> TimeUnit:
         """Unit of time. Defaults to `'us'` (microseconds)."""
@@ -627,8 +649,6 @@ class Categorical(DType):
         Categorical
     """
 
-    __slots__ = ()
-
 
 class Enum(DType):
     """A fixed categorical encoding of a unique set of strings.
@@ -658,9 +678,9 @@ class Enum(DType):
     @property
     def categories(self) -> tuple[str, ...]:
         """The categories in the dataset."""
-        if cached := self._cached_categories:
+        if (cached := self._cached_categories) is not None:
             return cached
-        if delayed := self._delayed_categories:
+        if (delayed := self._delayed_categories) is not None:
             self._cached_categories = delayed.to_tuple()
             return self._cached_categories
         msg = f"Internal structure of {type(self).__name__!r} is invalid."  # pragma: no cover
@@ -686,7 +706,7 @@ class Enum(DType):
             >>> nw.Enum(["a", "b", "c"]) == nw.Enum
             True
         """
-        if type(other) is type:
+        if type(other) is DTypeClass:
             return other is Enum
         return isinstance(other, type(self)) and self.categories == other.categories
 
@@ -801,7 +821,7 @@ class Struct(NestedType):
             >>> nw.Struct({"a": nw.Int64}) == nw.Struct
             True
         """
-        if type(other) is type and issubclass(other, self.__class__):
+        if type(other) is DTypeClass and issubclass(other, self.__class__):
             return True
         if isinstance(other, self.__class__):
             return self.fields == other.fields
@@ -864,7 +884,7 @@ class List(NestedType):
             >>> nw.List(nw.Int64) == nw.List
             True
         """
-        if type(other) is type and issubclass(other, self.__class__):
+        if type(other) is DTypeClass and issubclass(other, self.__class__):
             return True
         if isinstance(other, self.__class__):
             return self.inner == other.inner
@@ -937,7 +957,7 @@ class Array(NestedType):
             >>> nw.Array(nw.Int64, 2) == nw.Array
             True
         """
-        if type(other) is type and issubclass(other, self.__class__):
+        if type(other) is DTypeClass and issubclass(other, self.__class__):
             return True
         if isinstance(other, self.__class__):
             if self.shape != other.shape:
@@ -972,8 +992,6 @@ class Date(TemporalType):
         Date
     """
 
-    __slots__ = ()
-
 
 class Time(TemporalType):
     """Data type representing the time of day.
@@ -999,8 +1017,6 @@ class Time(TemporalType):
        Time
     """
 
-    __slots__ = ()
-
 
 class Binary(DType):
     """Binary type.
@@ -1024,5 +1040,3 @@ class Binary(DType):
         >>> nw.from_native(rel).collect_schema()["t"]
         Binary
     """
-
-    __slots__ = ()
