@@ -57,7 +57,7 @@ class SeriesStringNamespace(Generic[SeriesT]):
         """
         return self._narwhals_series._with_compliant(
             self._narwhals_series._compliant_series.str.replace(
-                pattern, self._extract_compliant(value), literal=literal, n=n
+                self._extract_compliant(value), pattern=pattern, literal=literal, n=n
             )
         )
 
@@ -83,7 +83,7 @@ class SeriesStringNamespace(Generic[SeriesT]):
         """
         return self._narwhals_series._with_compliant(
             self._narwhals_series._compliant_series.str.replace_all(
-                pattern, self._extract_compliant(value), literal=literal
+                self._extract_compliant(value), pattern, literal=literal
             )
         )
 
@@ -392,6 +392,43 @@ class SeriesStringNamespace(Generic[SeriesT]):
             self._narwhals_series._compliant_series.str.to_date(format=format)
         )
 
+    def to_titlecase(self) -> SeriesT:
+        """Modify strings to their titlecase equivalent.
+
+        Notes:
+            This is a form of case transform where the first letter of each word is
+            capitalized, with the rest of the word in lowercase.
+
+            Word boundaries are defined by non-**alphabetic** characters, matching the
+            behavior of [`str.title`](https://docs.python.org/3/library/stdtypes.html#str.title)
+
+        Examples:
+            >>> import pyarrow as pa
+            >>> import narwhals as nw
+            >>> s_native = pa.chunked_array(
+            ...     [
+            ...         [
+            ...             "'e.t. phone home'",
+            ...             "you talkin' to me?",
+            ...             "to infinity,and BEYOND!",
+            ...         ]
+            ...     ]
+            ... )
+            >>> s = nw.from_native(s_native, series_only=True)
+            >>> s.str.to_titlecase().to_native()  # doctest: +ELLIPSIS
+            <pyarrow.lib.ChunkedArray object at ...>
+            [
+              [
+                "'E.T. Phone Home'",
+                "You Talkin' To Me?",
+                "To Infinity,And Beyond!"
+              ]
+            ]
+        """
+        return self._narwhals_series._with_compliant(
+            self._narwhals_series._compliant_series.str.to_titlecase()
+        )
+
     def zfill(self, width: int) -> SeriesT:
         r"""Pad strings with zeros on the left.
 
@@ -413,3 +450,63 @@ class SeriesStringNamespace(Generic[SeriesT]):
         return self._narwhals_series._with_compliant(
             self._narwhals_series._compliant_series.str.zfill(width)
         )
+
+    def pad_start(self, length: int, fill_char: str = " ") -> SeriesT:
+        """Pad the start of the string until it reaches the given length.
+
+        Arguments:
+            length: Pad the string until it reaches this length. Strings with
+                length equal to or greater than this value are returned as-is.
+            fill_char: The character to pad the string with.
+
+        Examples:
+        >>> import pandas as pd
+        >>> import narwhals as nw
+        >>> df_native = pd.DataFrame({"a": ["cow", "monkey", "hippopotamus", None]})
+        >>> df = nw.from_native(df_native)
+        >>> df["a"].str.pad_start(8, "*")
+        ┌──────────────────────┐
+        |   Narwhals Series    |
+        |----------------------|
+        |0        *****cow     |
+        |1        **monkey     |
+        |2    hippopotamus     |
+        |3            None     |
+        |Name: a, dtype: object|
+        └──────────────────────┘
+        """
+        return self._narwhals_series._with_compliant(
+            self._narwhals_series._compliant_series.str.pad_start(
+                length=length, fill_char=fill_char
+            )
+        )
+
+    def pad_end(self, length: int, fill_char: str = " ") -> SeriesT:
+        """Pad the end of the string until it reaches the given length.
+
+        Arguments:
+            length: Pad the string until it reaches this length. Strings with
+                length equal to or greater than this value are returned as-is.
+            fill_char: The character to pad the string with.
+
+        Examples:
+        >>> import pandas as pd
+        >>> import narwhals as nw
+        >>> df_native = pd.DataFrame({"a": ["cow", "monkey", "hippopotamus", None]})
+        >>> df = nw.from_native(df_native)
+        >>> df["a"].str.pad_end(8, "*")
+        ┌──────────────────────┐
+        |   Narwhals Series    |
+        |----------------------|
+        |0        cow*****     |
+        |1        monkey**     |
+        |2    hippopotamus     |
+        |3            None     |
+        |Name: a, dtype: object|
+        └──────────────────────┘
+        """
+        return self._narwhals_series._with_compliant(
+            self._narwhals_series._compliant_series.str.pad_end(
+                length=length, fill_char=fill_char
+            )
+        )
